@@ -27,7 +27,9 @@ sub add {
     }
 
     # @args:
-    #   * [optional] params => {}
+    #   * [optional] named => []
+    #   * [optional] params => []
+    #   * [optional] path
     #   * [required] code ref
 
     my $code = pop @args;
@@ -37,20 +39,18 @@ sub add {
         return;
     }
 
-    # TODO: path params
-    # NOTE: IN PROGRESS
+    # Named route params
     if (scalar @args == 1 || scalar @args == 3) {
-        $path = $path . '/' . shift(@args);
-        warn $path;
+        $path = $path . '/' . pop @args;
     }
 
     my @params;
     if (@args && (my %args = @args)) {
         foreach my $key (qw(params named)) {
-            while (my @param = splice @{ $args{$key} }, 0, 2) {
+            for (my $i = 0; $i < scalar @{ $args{$key} || [] }; $i += 2) {
                 push @params, Raisin::Param->new(
                     named => $key eq 'named' ? 1 : 0,
-                    param => \@param
+                    param => [$args{$key}[$i], $args{$key}[$i + 1]]
                 );
             }
         }
@@ -96,8 +96,6 @@ sub find {
     my @found
     #   = sort { $b->bridge <=> $a->bridge || $a->pattern cmp $b->pattern }
         = grep { $_->match($method, $path) } @$routes;
-use DDP;
-p @found;
 
     $self->cache->{$cache_key} = \@found;
     \@found;
